@@ -33,7 +33,7 @@
 #ifndef __GNC_PLUGIN_PAGE_INVOICE_H
 #define __GNC_PLUGIN_PAGE_INVOICE_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 #include "Account.h"
 #include "gnc-ledger-display.h"
